"""QDialog for setup of CodeTableBase."""

from PySide2.QtWidgets import (
    QDialog,
    QVBoxLayout,
    QHBoxLayout,
    QLabel,
    QLineEdit,
    QComboBox,
    QFormLayout,
    QPushButton,
)
from PySide2.QtCore import Qt


class CodeTableSettings(QDialog):
    """Setup of CodeTableBase.

    Parameters
    ----------
    code_table_base : soitool.modules.code_table_base.CodeTableBase
        Is used to fetch the modules default values, so that these are
        pre-selected.
    """

    def __init__(self, code_table_base):
        super().__init__()

        # Hide help-button, disable close-button and set window width
        self.setWindowFlag(Qt.WindowContextHelpButtonHint, False)
        self.setWindowFlag(Qt.WindowCloseButtonHint, False)
        self.setFixedWidth(350)

        # Headline
        self.label_headline = QLabel("Overskrift")
        self.edit_headline = QLineEdit()
        self.edit_headline.setText(code_table_base.start_headline)

        # Number of codes
        self.label_no_of_codes = QLabel("Antall koder")
        self.combo_no_of_codes = QComboBox()
        for i in range(2, code_table_base.maximum_no_of_codes + 1):
            self.combo_no_of_codes.addItem(str(i))
        self.combo_no_of_codes.setCurrentIndex(
            code_table_base.start_no_of_codes - 2
        )

        # Code length
        self.label_code_length = QLabel("Kodelengde")
        self.combo_code_length = QComboBox()
        for i in range(2, 31):
            self.combo_code_length.addItem(str(i))
        self.combo_code_length.setCurrentIndex(code_table_base.code_length - 2)

        # Space interval
        self.label_space_interval = QLabel("Intervall for kodemellomrom")
        self.combo_space_interval = QComboBox()
        for i in range(11):
            self.combo_space_interval.addItem(str(i))
        self.combo_space_interval.setCurrentIndex(
            code_table_base.space_interval
        )

        # Space amount
        self.label_space_amount = QLabel("Mellomrom per intervall")
        self.combo_space_amount = QComboBox()
        for i in range(6):
            self.combo_space_amount.addItem(str(i))
        self.combo_space_amount.setCurrentIndex(code_table_base.space_amount)

        # Create-button
        self.button_create = QPushButton("Opprett")
        self.button_create.clicked.connect(self.accept)

        self.create_and_set_layout()

    def create_and_set_layout(self):
        """Create layouts, add widgets and set layout."""
        # Layout for input-widgets
        self.form_layout = QFormLayout()
        self.form_layout.addRow(self.label_headline, self.edit_headline)
        self.form_layout.addRow(self.label_no_of_codes, self.combo_no_of_codes)
        self.form_layout.addRow(self.label_code_length, self.combo_code_length)
        self.form_layout.addRow(
            self.label_space_interval, self.combo_space_interval
        )
        self.form_layout.addRow(
            self.label_space_amount, self.combo_space_amount
        )

        # Layout for create-button
        self.button_layout = QHBoxLayout()
        self.button_layout.addWidget(self.button_create)

        # Main layout
        self.main_layout = QVBoxLayout()
        self.main_layout.addLayout(self.form_layout)
        self.main_layout.addLayout(self.button_layout)

        self.setLayout(self.main_layout)
